//////////////////////////////////////////////////////////////////////
// MLInterface.h: interface for the MLInterface class.
// 
//	Purpose
// This is the interface between Matlab and the MLGAMain module
// Here are defined the names of the elements of the structures used
// to communicate. If you change the names you have to change the calls 
// from mathlab
// 
//////////////////////////////////////////////////////////////////////

#include "mex.h"
#include "mlio.h"

#if !defined(AFX_MLINTERFACE_H__E18F5C01_50F7_11D4_8F70_98BF294E0958__INCLUDED_)
#define AFX_MLINTERFACE_H__E18F5C01_50F7_11D4_8F70_98BF294E0958__INCLUDED_

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000

//////////////////////////////////////////////////////////////////////////
// The usual names of the variables and their translation
// as constants. !! the call from mathlab is case sensitive !!
///////////////////////////
// user data
// double vars
#define sXsize	"inXsize"
#define sDsize	"inDsize"
// array defs
#define sXopt	"inXopt"
#define sXwei	"inXwei"
#define sXval	"inXval"
#define sXmin	"inXmin"
#define sXmax	"inXmax"
#define sDwei	"inDwei"

////////////////////////////
// Parameters
#define sN_POP   "inN_POP"
#define sN_GEN   "inN_GEN"
#define sP_MUT   "inP_MUT"
#define sP_CRO   "inP_CRO"
#define sBCOname "BCOname"		// 'Bin'
#define sBCOBmut "BCOBmut"		// 0.01
#define sBCOIdep "BCOIdep"		// 1.0
#define sBCORdep "BCORdep"		// 0.5

////////////////////////////
// Control Data
#define sPlot	"PnPlot"
#define sTrace	"PTrace"


class MLInterface  
{
public:
				MLInterface();
	virtual		~MLInterface();
	void		SetArgs(const mxArray *Arg);
	void		SetArgs(const mxArray *Arg, bool Clone);
	mxArray		*GetArgs();
	double		ReadDouble( char *Name );
	char		*ReadString( char *Name );
	double		*ReadArray( char *Name, int *SizeM, int *SizeN );
	double		*ReadArray( char *Name )
		{
		int SizeM, SizeN;
		return ReadArray(Name, &SizeM, &SizeN);
		}

	void		PrintArg();

private:
	const mxArray			*m_ArgNorm;
	mxArray					*m_ArgClone;
	bool					m_Clone;
};

#endif // !defined(AFX_MLINTERFACE_H__E18F5C01_50F7_11D4_8F70_98BF294E0958__INCLUDED_)
