//static const char *version="MixedGenome Header v1.0 Adam Molyneaux 1April/97\n";
/* ----------------------------------------------------------------------------
  mixed.h
  akm 1April97
  Copyright (c) 1997 Adam K Molyneaux
                     all rights reserved

 DESCRIPTION:
 A mixed integer and real genome.

 MODIFICATIONS:
 21December2000 - Blaise Renaud
	- Created GAIntBlendCrossover, a direct translation from GARealBlendCrossover
		Enlarging by deploying the exploitation interval of each gene (100% both side)
		And taking care of the limits.
	- Created GABinBlendCrossover for binary genome
		Standard binary generation, with some kind of mutation if parents' genes are the same.
		
---------------------------------------------------------------------------- */
#ifndef _GA_MIXED_GENOME_H_
#define _GA_MIXED_GENOME_H_
#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <math.h>
//#include <ga.h>
#include <ga/GAAlleleF.h>
#include <ga/GA1DArrayGenomeF.h>
#include "MLInterface.h"


int  GARealBlendCrossover(const GAGenome& p1, const GAGenome& p2,GAGenome* c1, GAGenome* c2);
int  GAListBlendCrossover(const GAGenome& p1, const GAGenome& p2,GAGenome* c1, GAGenome* c2);
int  GAIntBlendCrossover(const GAGenome& p1, const GAGenome& p2,GAGenome* c1, GAGenome* c2);
int  GABinBlendCrossover(const GAGenome& p1, const GAGenome& p2,GAGenome* c1, GAGenome* c2);

class MixedGenome : public GAGenome {
public:
  GADefineIdentity("MixedGenome", 245);

  static void  MixedInitializer(GAGenome&);
  static int MixedMutator(GAGenome&, float);
  static float MixedComparator(const GAGenome&, const GAGenome&);
  static int MixedCrossover(const GAGenome&, const GAGenome&,
				GAGenome*, GAGenome*);
public:
  MixedGenome(GAAlleleSetArray &float_allele,GAAlleleSetArray &int_allele,
		  GAGenome::Evaluator f=NULL, void* u=NULL);
  MixedGenome(const MixedGenome & orig);
  MixedGenome& operator=(const GAGenome& g);
  virtual ~MixedGenome();
  virtual GAGenome* clone(GAGenome::CloneMethod) const ;
  virtual void copy(const GAGenome & c);
  virtual int equal(const GAGenome& g) const;
  virtual int read(istream & is);
  virtual int write(ostream & os) const;

  GA1DArrayAlleleGenome & real_genome() const {return *_greal;}
  GA1DArrayAlleleGenome & int_genome() const {return *_gint;}

protected:
  GA1DArrayAlleleGenome *_greal;
  GA1DArrayAlleleGenome *_gint;
};

#endif

